SCuBA GWS Secure Configuration Baseline Reports

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# SCuBA GWS Secure Configuration Baseline Reports

Customer Name | Customer Domain | Customer ID | Report Date
--- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:23 Pacific Daylight Time

Baseline Conformance Reports | Details
--- | ---
Google Calendar | 4 passes 1 failure 1 manual check
Google Chat | 7 passes
Google Classroom | 6 passes
Common Controls | 8 passes 3 warnings 17 failures 14 manual checks
Google Drive and Docs | 10 passes 2 warnings 4 failures
Gmail | 19 passes 4 warnings 8 failures 10 manual checks
Groups for Business | 6 passes
Google Meet | 3 passes 1 warning 3 manual checks
Google Sites | 1 pass